"use strict";

var foo4 = babelHelpers.interopRequireWildcard(require("foo"));
foo4.default;
foo4.default;
foo4.foo3;
(0, foo4.foo3)();
(0, foo4.foo3)``;
(0, foo4.foo3)?.();
